from io import BytesIO

from google.cloud import storage


def get_storage_client_from_service_account(service_account_info):
    return storage.Client.from_service_account_info(service_account_info)


def get_storage_client_from_local_auth(project_id: str = None):
    return (
        storage.Client() if project_id is None else storage.Client(project=project_id)
    )


def upload_blob_from_input_bytes(
    client, bucket_name, input_bytes: BytesIO, destination_blob_name
):
    bucket = client.get_bucket(bucket_name)
    blob = bucket.blob(destination_blob_name)
    blob.upload_from_string(input_bytes.getvalue(), content_type="binary/octet-stream")


def download_file(client, bucket_name, object_name):
    bucket = client.get_bucket(bucket_name)
    blob = bucket.blob(object_name)
    return blob.download_as_bytes()
